"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useLangSearch = exports.isPartial = exports.getFirstFullTemplateId = exports.findById = exports.default = exports.URL_NAME = void 0;

var _react = _interopRequireDefault(require("react"));

var _lodash = require("lodash");

var _q3UiRest = _interopRequireDefault(require("q3-ui-rest"));

var _q3UiPermissions = require("q3-ui-permissions");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// eslint-disable-next-line
const URL_NAME = 'emails';
exports.URL_NAME = URL_NAME;

const isPartial = xs => !(xs !== null && xs !== void 0 && xs.name) || String(xs.name).startsWith('__');

exports.isPartial = isPartial;

const findById = (xs, id) => (0, _lodash.find)(xs, item => (item === null || item === void 0 ? void 0 : item.id) === id);

exports.findById = findById;

const getFirstFullTemplateId = xs => {
  var _find;

  return (_find = (0, _lodash.find)(xs, item => !isPartial(item))) === null || _find === void 0 ? void 0 : _find.id;
};

exports.getFirstFullTemplateId = getFirstFullTemplateId;

const noop = () => Promise.resolve(null);

const useLangSearch = () => {
  const lang = (0, _q3UiPermissions.useProfileLang)();
  return `?sort=name&limit=500&name=in(/^${lang}/gi,/^__class/gi,/^__${lang}/gi)`;
};

exports.useLangSearch = useLangSearch;

const useEmailTemplates = () => {
  const search = useLangSearch();
  const {
    emails = [],
    fetchingError = false,
    fetching = true,
    patch,
    poll,
    remove
  } = (0, _q3UiRest.default)({
    key: 'email',
    pluralized: URL_NAME,
    url: `/${URL_NAME}`,
    runOnInit: true,
    location: {
      search
    }
  });
  const {
    canSee
  } = (0, _q3UiPermissions.useAuth)(URL_NAME);

  const [active, setActive] = _react.default.useState();

  const current = findById(emails, active);
  /**
   * Forcing async because try/catch logic
   * Hadn't previously worked as a promise.
   */

  const handleRevert = async () => {
    try {
      if ( // eslint-disable-next-line
      confirm('Reverting discards any and all changes made to this email template. This action is irreversible.')) {
        await remove(active)();
        return poll(search);
      }

      return noop();
    } catch (e) {
      return noop();
    }
  };

  const handleSave = mjml => patch(active)({
    mjml
  });

  _react.default.useEffect(() => {
    if ((0, _lodash.size)(emails) && !active) setActive(getFirstFullTemplateId(emails));
  }, [emails]);

  return {
    templates: emails,
    error: Boolean(fetchingError || !(0, _lodash.size)(emails) || !canSee),
    ready: Boolean(!fetching && current) || fetchingError,
    disablePreview: isPartial(current),
    value: (current === null || current === void 0 ? void 0 : current.mjml) || '<mjml />',
    variables: (0, _lodash.get)(current, 'variables', {}),
    onRevert: handleRevert,
    onSave: handleSave,
    setById: setActive,
    id: active
  };
};

var _default = useEmailTemplates;
exports.default = _default;